@@ -42,32 +42,27 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include "micmap.h"
 #include "globals.h"
 #include "glxserver.h"
+#include "extinit.h"
 
 static MODULESETUPPROTO(glxSetup);
 
-static const char *initdeps[] = { "DOUBLE-BUFFER", "COMPOSITE", NULL };
-
-static ExtensionModule GLXExt =
-{
+static ExtensionModule GLXExt = {
     GlxExtensionInit,
     "GLX",
-    &noGlxExtension,
-    NULL,
-    initdeps
+    &noGlxExtension
 };
 
-static XF86ModuleVersionInfo VersRec =
-{
-        "glx",
-        MODULEVENDORSTRING,
-        MODINFOSTRING1,
-        MODINFOSTRING2,
-        XORG_VERSION_CURRENT,
-        1, 0, 0,
-        ABI_CLASS_EXTENSION,
-        ABI_EXTENSION_VERSION,
-        MOD_CLASS_NONE,
-        {0,0,0,0}
+static XF86ModuleVersionInfo VersRec = {
+    "glx",
+    MODULEVENDORSTRING,
+    MODINFOSTRING1,
+    MODINFOSTRING2,
+    XORG_VERSION_CURRENT,
+    1, 0, 0,
+    ABI_CLASS_EXTENSION,
+    ABI_EXTENSION_VERSION,
+    MOD_CLASS_NONE,
+    {0, 0, 0, 0}
 };
 
 _X_EXPORT XF86ModuleData glxModuleData = { &VersRec, glxSetup, NULL };
@@ -79,41 +74,22 @@ glxSetup(pointer module, pointer opts, int *errmaj, int *errmin)
     __GLXprovider *provider;
 
     if (setupDone) {
-	if (errmaj) *errmaj = LDR_ONCEONLY;
-	return NULL;
-    } 
+        if (errmaj)
+            *errmaj = LDR_ONCEONLY;
+        return NULL;
+    }
 
     setupDone = TRUE;
 
-    provider = LoaderSymbol("__glXDRISWRastProvider");
-    if (provider == NULL)
-	return NULL;
-    GlxPushProvider(provider);
-
-    xf86Msg(xf86Info.aiglxFrom, "AIGLX %s\n", 
-	    xf86Info.aiglx ? "enabled" : "disabled");
+    xf86Msg(xf86Info.aiglxFrom, "AIGLX %s\n",
+            xf86Info.aiglx ? "enabled" : "disabled");
     if (xf86Info.aiglx) {
-      provider = LoaderSymbol("__glXDRIProvider");
-      if (provider)
-	GlxPushProvider(provider);
-      provider = LoaderSymbol("__glXDRI2Provider");
-      if (provider)
-	GlxPushProvider(provider);
-    }
-
-    switch (xf86Info.glxVisuals) {
-    case XF86_GlxVisualsMinimal:
-	GlxSetVisualConfig(GLX_MINIMAL_VISUALS);
-	xf86Msg(xf86Info.aiglxFrom, "Exporting only minimal set of GLX visuals\n");
-	break;
-    case XF86_GlxVisualsTypical:
-	GlxSetVisualConfig(GLX_TYPICAL_VISUALS);
-	xf86Msg(xf86Info.aiglxFrom, "Exporting typical set of GLX visuals\n");
-	break;
-    case XF86_GlxVisualsAll:
-	GlxSetVisualConfig(GLX_ALL_VISUALS);
-	xf86Msg(xf86Info.aiglxFrom, "Exporting all GLX visuals\n");
-	break;
+        provider = LoaderSymbol("__glXDRIProvider");
+        if (provider)
+            GlxPushProvider(provider);
+        provider = LoaderSymbol("__glXDRI2Provider");
+        if (provider)
+            GlxPushProvider(provider);
     }
 
     LoadExtension(&GLXExt, FALSE);
